package edu.nyu.scps.cursor;

import android.app.LoaderManager;
import android.content.CursorLoader;
import android.content.Loader;
import android.database.Cursor;
import android.net.Uri;
import android.os.Bundle;
import android.provider.ContactsContract;
import android.support.v7.app.AppCompatActivity;
import android.view.Menu;
import android.view.MenuItem;
import android.widget.TextView;


public class MainActivity extends AppCompatActivity implements
        LoaderManager.LoaderCallbacks<Cursor> {

    private Uri uri = ContactsContract.Contacts.CONTENT_URI;

    private String[] projection = {
            ContactsContract.Contacts._ID,
            ContactsContract.Contacts.DISPLAY_NAME
    };

    //ASC means "ascending", not "ASCII".
    private String sortOrder = ContactsContract.Contacts.DISPLAY_NAME + " COLLATE LOCALIZED ASC";

    private static final int LOADER_ID = 0;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        LoaderManager loaderManager = getLoaderManager();
        loaderManager.initLoader(LOADER_ID, null, this); //will call onCreateLoader
    }

    @Override
    public Loader<Cursor> onCreateLoader(int id, Bundle args) {
        if (id == LOADER_ID) {
            //This CursorLoader will be passed to onLoadFinished.
            return new CursorLoader(this, uri, projection, null, null, sortOrder);
        }
        return null;
    }

    //onLoadFinished will receive the CursorLoader created by onCreateLoader.
    //onLoadFinished will also be called whenever the contacts database changes.

    @Override
    public void onLoadFinished(Loader<Cursor> loader, Cursor cursor) {
        TextView textView = (TextView)findViewById(R.id.textView);

        textView.setText("The name of the table is\n" + uri + "\n\n"
            + "The sort order is\n" + sortOrder + "\n\n"
            + "We will read " + projection.length + " column(s):\n");

        for (String name: projection) {
            textView.append(cursor.getColumnIndex(name) + " " + name + "\n");
        }

        textView.append("\nWe will read " + cursor.getCount() + " row(s):\n");

        if (!cursor.moveToFirst()) {
            return;
        }

        int idIndex          = cursor.getColumnIndex(ContactsContract.Data._ID);
        int displayNameIndex = cursor.getColumnIndex(ContactsContract.Data.DISPLAY_NAME);

        do {
            textView.append(cursor.getString(idIndex) + " " + cursor.getString(displayNameIndex) + "\n");
        } while (cursor.moveToNext());
    }

    @Override
    public void onLoaderReset(Loader<Cursor> loader) {
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        }

        return super.onOptionsItemSelected(item);
    }

}
